@@ -40,36 +40,36 @@ func galMulSSSE3Xor(low, high, in, out []byte) {
 }
 */
 
-func galMulSlice(c byte, in, out []byte, ssse3, avx2 bool) {
+func galMulSlice(c byte, in, out []byte, o *options) {
 	var done int
-	if avx2 {
+	if o.useAVX2 {
 		galMulAVX2(mulTableLow[c][:], mulTableHigh[c][:], in, out)
 		done = (len(in) >> 5) << 5
-	} else if ssse3 {
+	} else if o.useSSSE3 {
 		galMulSSSE3(mulTableLow[c][:], mulTableHigh[c][:], in, out)
 		done = (len(in) >> 4) << 4
 	}
 	remain := len(in) - done
 	if remain > 0 {
-		mt := mulTable[c]
+		mt := mulTable[c][:256]
 		for i := done; i < len(in); i++ {
 			out[i] = mt[in[i]]
 		}
 	}
 }
 
-func galMulSliceXor(c byte, in, out []byte, ssse3, avx2 bool) {
+func galMulSliceXor(c byte, in, out []byte, o *options) {
 	var done int
-	if avx2 {
+	if o.useAVX2 {
 		galMulAVX2Xor(mulTableLow[c][:], mulTableHigh[c][:], in, out)
 		done = (len(in) >> 5) << 5
-	} else if ssse3 {
+	} else if o.useSSSE3 {
 		galMulSSSE3Xor(mulTableLow[c][:], mulTableHigh[c][:], in, out)
 		done = (len(in) >> 4) << 4
 	}
 	remain := len(in) - done
 	if remain > 0 {
-		mt := mulTable[c]
+		mt := mulTable[c][:256]
 		for i := done; i < len(in); i++ {
 			out[i] ^= mt[in[i]]
 		}
