@@ -31,28 +31,28 @@ func galMulPpcXor(low, high, in, out []byte) {
 }
 */
 
-func galMulSlice(c byte, in, out []byte, ssse3, avx2 bool) {
+func galMulSlice(c byte, in, out []byte, o *options) {
 	done := (len(in) >> 4) << 4
 	if done > 0 {
 		galMulPpc(mulTableLow[c][:], mulTableHigh[c][:], in[:done], out)
 	}
 	remain := len(in) - done
 	if remain > 0 {
-		mt := mulTable[c]
+		mt := mulTable[c][:256]
 		for i := done; i < len(in); i++ {
 			out[i] = mt[in[i]]
 		}
 	}
 }
 
-func galMulSliceXor(c byte, in, out []byte, ssse3, avx2 bool) {
+func galMulSliceXor(c byte, in, out []byte, o *options) {
 	done := (len(in) >> 4) << 4
 	if done > 0 {
 		galMulPpcXor(mulTableLow[c][:], mulTableHigh[c][:], in[:done], out)
 	}
 	remain := len(in) - done
 	if remain > 0 {
-		mt := mulTable[c]
+		mt := mulTable[c][:256]
 		for i := done; i < len(in); i++ {
 			out[i] ^= mt[in[i]]
 		}
@@ -65,3 +65,6 @@ func sliceXor(in, out []byte, sse2 bool) {
 		out[n] ^= input
 	}
 }
+
+func (r reedSolomon) codeSomeShardsAvx512(matrixRows, inputs, outputs [][]byte, outputCount, byteCount int) {
+}
